@@ -1,4 +1,4 @@
-from .writers import get_writer, format_timestamp
+from .writers import format_timestamp
 from typing import NamedTuple, Optional, List, Union
 import tqdm
 import sys
@@ -72,8 +72,6 @@ class Transcribe:
         self,
         audio: str,
         model_path: str,
-        output_dir: str,
-        output_format: str,
         task: str,
         language: str,
         threads: int,
@@ -129,15 +127,15 @@ class Transcribe:
             total=info.duration, unit="seconds", disable=verbose is not False
         ) as pbar:
             for segment in segments:
-                if verbose:
-                    start, end, text = segment.start, segment.end, segment.text
+                start, end, text = segment.start, segment.end, segment.text
+                all_text += segment.text
 
+                if verbose or options.print_colors:
                     if options.print_colors and segment.words:
                         text = self._get_colored_text(segment.words)
                     else:
                         text = segment.text
 
-                    all_text += text
                     line = f"[{format_timestamp(start)} --> {format_timestamp(end)}] {text}"
                     print(make_safe(line))
 
